==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachinePropertiesNetworkProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesNetworkProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * NetworkProfile - describes the network configuration the virtual machine
 * @property networkInterfaces NetworkInterfaces - list of network interfaces to be attached to the virtual machine
 */
public data class VirtualMachinePropertiesNetworkProfileArgs(
    public val networkInterfaces: Output<List<VirtualMachinePropertiesNetworkInterfacesArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesNetworkProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesNetworkProfileArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesNetworkProfileArgs.builder()
            .networkInterfaces(
                networkInterfaces?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualMachinePropertiesNetworkProfileArgs].
 */
@PulumiTagMarker
public class VirtualMachinePropertiesNetworkProfileArgsBuilder internal constructor() {
    private var networkInterfaces: Output<List<VirtualMachinePropertiesNetworkInterfacesArgs>>? = null

    /**
     * @param value NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("qieporghflbvscka")
    public suspend
    fun networkInterfaces(`value`: Output<List<VirtualMachinePropertiesNetworkInterfacesArgs>>) {
        this.networkInterfaces = value
    }

    @JvmName("hffnrxogyfnqtiqp")
    public suspend fun networkInterfaces(
        vararg
        values: Output<VirtualMachinePropertiesNetworkInterfacesArgs>,
    ) {
        this.networkInterfaces = Output.all(values.asList())
    }

    /**
     * @param values NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("sxgyexbqdxuetyit")
    public suspend
    fun networkInterfaces(values: List<Output<VirtualMachinePropertiesNetworkInterfacesArgs>>) {
        this.networkInterfaces = Output.all(values)
    }

    /**
     * @param value NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("kgsouyfvtjdjxaag")
    public suspend
    fun networkInterfaces(`value`: List<VirtualMachinePropertiesNetworkInterfacesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkInterfaces = mapped
    }

    /**
     * @param argument NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("sfruerpumumrarsu")
    public suspend
    fun networkInterfaces(argument: List<suspend VirtualMachinePropertiesNetworkInterfacesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachinePropertiesNetworkInterfacesArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.networkInterfaces = mapped
    }

    /**
     * @param argument NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("kevmvylfynhfufdb")
    public suspend fun networkInterfaces(
        vararg
        argument: suspend VirtualMachinePropertiesNetworkInterfacesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachinePropertiesNetworkInterfacesArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.networkInterfaces = mapped
    }

    /**
     * @param argument NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("amvsbvcgwveqldtj")
    public suspend
    fun networkInterfaces(argument: suspend VirtualMachinePropertiesNetworkInterfacesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachinePropertiesNetworkInterfacesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.networkInterfaces = mapped
    }

    /**
     * @param values NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("paljhhuwvtdlucqy")
    public suspend fun networkInterfaces(
        vararg
        values: VirtualMachinePropertiesNetworkInterfacesArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkInterfaces = mapped
    }

    internal fun build(): VirtualMachinePropertiesNetworkProfileArgs =
        VirtualMachinePropertiesNetworkProfileArgs(
            networkInterfaces = networkInterfaces,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachinePropertiesNetworkProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesNetworkProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * NetworkProfile - describes the network configuration the virtual machine
 * @property networkInterfaces NetworkInterfaces - list of network interfaces to be attached to the virtual machine
 */
public data class VirtualMachinePropertiesNetworkProfileArgs(
    public val networkInterfaces: Output<List<VirtualMachinePropertiesNetworkInterfacesArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesNetworkProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesNetworkProfileArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesNetworkProfileArgs.builder()
            .networkInterfaces(
                networkInterfaces?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualMachinePropertiesNetworkProfileArgs].
 */
@PulumiTagMarker
public class VirtualMachinePropertiesNetworkProfileArgsBuilder internal constructor() {
    private var networkInterfaces: Output<List<VirtualMachinePropertiesNetworkInterfacesArgs>>? = null

    /**
     * @param value NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("xecggfusfgajibhv")
    public suspend
    fun networkInterfaces(`value`: Output<List<VirtualMachinePropertiesNetworkInterfacesArgs>>) {
        this.networkInterfaces = value
    }

    @JvmName("blikwxpgpounlpdq")
    public suspend fun networkInterfaces(
        vararg
        values: Output<VirtualMachinePropertiesNetworkInterfacesArgs>,
    ) {
        this.networkInterfaces = Output.all(values.asList())
    }

    /**
     * @param values NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("spprgoyysraqxplx")
    public suspend
    fun networkInterfaces(values: List<Output<VirtualMachinePropertiesNetworkInterfacesArgs>>) {
        this.networkInterfaces = Output.all(values)
    }

    /**
     * @param value NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("xpuanpdaqsquhfqc")
    public suspend
    fun networkInterfaces(`value`: List<VirtualMachinePropertiesNetworkInterfacesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkInterfaces = mapped
    }

    /**
     * @param argument NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("tabioivclfysbcpr")
    public suspend
    fun networkInterfaces(argument: List<suspend VirtualMachinePropertiesNetworkInterfacesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachinePropertiesNetworkInterfacesArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.networkInterfaces = mapped
    }

    /**
     * @param argument NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("cjyhhntehdamorla")
    public suspend fun networkInterfaces(
        vararg
        argument: suspend VirtualMachinePropertiesNetworkInterfacesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachinePropertiesNetworkInterfacesArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.networkInterfaces = mapped
    }

    /**
     * @param argument NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("nykldrowdhpaxsch")
    public suspend
    fun networkInterfaces(argument: suspend VirtualMachinePropertiesNetworkInterfacesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachinePropertiesNetworkInterfacesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.networkInterfaces = mapped
    }

    /**
     * @param values NetworkInterfaces - list of network interfaces to be attached to the virtual machine
     */
    @JvmName("xmplfleepssxuswo")
    public suspend fun networkInterfaces(
        vararg
        values: VirtualMachinePropertiesNetworkInterfacesArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkInterfaces = mapped
    }

    internal fun build(): VirtualMachinePropertiesNetworkProfileArgs =
        VirtualMachinePropertiesNetworkProfileArgs(
            networkInterfaces = networkInterfaces,
        )
}
